clean_architecture_with_state_management library

Clean Architecture with State Management

A CLI tool to generate clean architecture boilerplate with various state management solutions.

Classes

CLIHelper
Helper class for interactive CLI operations with colors and prompts
FileCreator
Global state management for file creation

Extensions

StringExtension on String

Functions

addBlocFiles(String featureName) → void
Creates the necessary files for a Bloc feature.
addBlocPackage() Future<void>
addCubitFiles(String featureName) → void
Creates the necessary Cubit files for a feature in the presentation layer.
addProviderPackage() Future<void>
Adds the Provider package to the project using the flutter pub add command.
addRiverpodPackage() Future<void>
createCleanArchitectureBlocFiles(String featureName) Future
Creates the necessary files for a clean architecture using the BLoC pattern.
createCleanArchitectureCubitFiles(String featureName) Future
Creates the necessary files for a clean architecture using the Cubit pattern.
createCleanArchitectureFiles(String featureName) Future
createCleanArchitectureProviderFiles(String featureName) Future
Creates the necessary files for a clean architecture using the Provider pattern.
createCleanArchitectureRiverpodFiles(String featureName) Future<void>
Creates the necessary files for a clean architecture using the Riverpod pattern.
createDataFiles(String featureName) → void
Creates data files for a feature.
createDirectories(String featureName) → void
Creates the necessary directories for a clean architecture feature.
createDomainFiles(String featureName) → void
createInitParamsFile(String featureName) → void
Creates an initialization parameters file for the given feature.
createPresentationFiles(String featureName) → void
Creates a presentation file for the given featureName, generating a screen with a basic Scaffold and a Placeholder widget.
generateScreenCode(String featureName) String
init(String featureName) Future<void>
Initializes the feature by creating the injection container file if it doesn't exist.